@@ -18,13 +18,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.92 2006/07/04 05:15:35 lav Exp $ */
+/* $Id: FileAccess.h,v 1.93.2.1 2007/04/05 13:23:35 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
 
-#include "SMTask.h"
-#include "trio.h"
 #include <time.h>
 #include <sys/types.h>
 
@@ -38,15 +36,13 @@
 # include <poll.h>
 #endif
 
+#include "SMTask.h"
+#include "trio.h"
 #include "xmalloc.h"
 #include "ResMgr.h"
 #include "FileSet.h"
 #include "LsCache.h"
 
-#define NO_SIZE	     ((off_t)-1L)
-#define NO_SIZE_YET  ((off_t)-2L)
-#define NO_DATE	     ((time_t)-1L)
-#define NO_DATE_YET  ((time_t)-2L)
 #define FILE_END     ((off_t)-1L)
 #define UNKNOWN_POS  ((off_t)-1L)
 
@@ -143,7 +139,7 @@ protected:
    off_t real_pos;
    off_t limit;
 
-   time_t *opt_date;
+   FileTimestamp *opt_date;
    off_t  *opt_size;
 
    static void NonBlock(int fd);
@@ -248,7 +244,7 @@ public:
    void SetLimit(off_t lim) { limit=lim; }
    void SetSize(off_t s) { entity_size=s; }
    void SetDate(time_t d) { entity_date=d; }
-   void WantDate(time_t *d) { opt_date=d; }
+   void WantDate(FileTimestamp *d) { opt_date=d; }
    void WantSize(off_t *s) { opt_size=s; }
    void AsciiTransfer() { ascii=true; }
    virtual void Close();
@@ -445,14 +441,7 @@ public:
    void SetExclude(const char *p,PatternSet *e);
 
    // caller has to delete the resulting FileSet itself.
-   FileSet *GetResult()
-      {
-	 FileSet *tmp=result;
-      	 result=0;
-	 return tmp;
-	 // miss := (assign and return old value) :(
-      	 // return result:=0;
-      }
+   FileSet *GetResult() { return replace_value(result,(FileSet*)0); }
 
    void Need(unsigned mask) { need|=mask; }
    void NoNeed(unsigned mask) { need&=~mask; }
