@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.126.2.1 2007/04/05 13:23:36 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.126.2.3 2007/08/23 06:58:18 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -949,7 +949,7 @@ void FileCopyPeerFA::OpenSession()
       if(try_time!=0)
 	 session->SetTryTime(try_time);
       if(retries!=0)
-	 session->SetRetries(retries);
+	 session->SetRetries(retries+1);
       if(e_size!=NO_SIZE && e_size!=NO_SIZE_YET)
 	 session->SetSize(e_size);
       if(date!=NO_DATE && date!=NO_DATE_YET)
@@ -1376,6 +1376,11 @@ int FileCopyPeerFDStream::Do()
       return m;
    }
 
+   bool check_min_size=true;
+#ifndef NATIVE_CRLF
+   if(ascii)
+      check_min_size=false;
+#endif
    switch(mode)
    {
    case PUT:
@@ -1405,7 +1410,7 @@ int FileCopyPeerFDStream::Do()
 	 return m;
       while(in_buffer>0)
       {
-	 if(!eof && in_buffer<PUT_LL_MIN
+	 if(check_min_size && !eof && in_buffer<PUT_LL_MIN
 	 && put_ll_timer && !put_ll_timer->Stopped())
 	    break;
 	 int res=Put_LL(buffer+buffer_ptr,in_buffer);
