@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Filter.h,v 1.18 2005/03/13 12:17:59 lav Exp $ */
+/* $Id: Filter.h,v 1.23.2.1 2007/04/05 13:23:38 lav Exp $ */
 
 #ifndef FILTER_H
 #define FILTER_H
@@ -26,6 +26,7 @@
 #include "ProcWait.h"
 
 class ArgV;
+class FileTimestamp;
 
 class FDStream
 {
@@ -34,6 +35,8 @@ class FDStream
 public:
    int fd;
    char *name;
+   char *full_name;
+   char *cwd;
    char *error_text;
    const char *status;
 
@@ -51,15 +54,18 @@ public:
    void clear_status() { status=0; }
    void CloseFD() { close_fd=true; }
 
+   void SetCwd(const char *);
+   const char *GetCwd() const { return cwd; }
+
    virtual off_t get_size() { return -1; }
-   virtual void setmtime(time_t) {}
+   virtual void setmtime(const FileTimestamp &) {}
    virtual bool can_setmtime() { return false; }
    virtual void remove_if_empty() {}
    virtual void remove() {}
    virtual bool Done() { return true; }
    virtual bool usesfd(int n_fd) { return fd==n_fd; }
    virtual void Kill(int=SIGTERM) {}
-   virtual pid_t GetProcGroup() { return 0; }
+   virtual pid_t GetProcGroup() const { return 0; }
    virtual bool broken() { return false; }
    virtual bool can_seek() { return false; }
 };
@@ -72,8 +78,7 @@ class OutputFilter : public FDStream
    FDStream *second;
    bool delete_second;
    bool stderr_to_stdout;
-
-   char *oldcwd;
+   bool stdout_to_null;
 
    bool closed;
 
@@ -92,15 +97,18 @@ public:
    OutputFilter(ArgV *a,FDStream *second);
    virtual ~OutputFilter();
 
-   void SetCwd(const char *);
    void StderrToStdout() { stderr_to_stdout=true; }
+   void StdoutToNull() { stdout_to_null=true; }
 
    int getfd();
    bool Done();
 
    bool usesfd(int n_fd);
    void Kill(int sig=SIGTERM);
-   pid_t GetProcGroup() { return pg; }
+   pid_t GetProcGroup() const { return pg; }
+   void SetProcGroup(pid_t new_pg) { pg=new_pg; }
+   ProcWait::State GetProcState() { return w->GetState(); }
+   int GetProcExitCode() { return w->GetInfo()>>8; }
 
    bool broken();
 
@@ -126,11 +134,10 @@ class FileStream : public FDStream
 {
    int mode;
 public:
-   char *full_name;
    FileStream(const char *fname,int open_mode);
    ~FileStream();
 
-   void setmtime(time_t t);
+   void setmtime(const FileTimestamp &);
    bool can_setmtime() { return true; }
    void remove_if_empty();
    void remove();
