@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: LocalAccess.h,v 1.7 2000/01/22 16:27:29 lav Exp $ */
+/* $Id: LocalAccess.h,v 1.12 2006/06/13 14:35:38 lav Exp $ */
 
 #ifndef LOCALACCESS_H
 #define LOCALACCESS_H
@@ -43,10 +43,10 @@ public:
    void AnonymousLogin() {}
    void Login(const char *u,const char *p) {}
 
-   const char *GetProto() { return "file"; }
-   FileAccess *Clone() { return new LocalAccess(this); }
+   const char *GetProto() const { return "file"; }
+   FileAccess *Clone() const { return new LocalAccess(this); }
    static FileAccess *New();
-   bool SameLocationAs(FileAccess *fa);
+   bool SameLocationAs(const FileAccess *fa) const;
 
    int Read(void *buf,int size);
    int Write(const void *buf,int size);
@@ -55,33 +55,26 @@ public:
    int Done();
    void Close();
 
+   const char *CurrentStatus();
+
    static void ClassInit();
 
-   ListInfo *MakeListInfo();
+   ListInfo *MakeListInfo(const char *path);
    Glob	    *MakeGlob(const char *pattern);
    DirList  *MakeDirList(ArgV *a);
 };
 
 class LocalListInfo : public ListInfo
 {
-   const char *dir;
 public:
-   LocalListInfo(const char *d) { dir=d; }
-   const char *Status() { return "..."; }
-   int Do();
-};
-
-class LocalGlob : public Glob
-{
-   const char *cwd;
-public:
-   LocalGlob(const char *cwd,const char *pattern);
+   LocalListInfo(FileAccess *s,const char *d) : ListInfo(s,d) {}
    const char *Status() { return "..."; }
    int Do();
 };
 
 class LocalDirList : public DirList
 {
+   IOBuffer *ubuf;
    FgData *fg_data;
 public:
    LocalDirList(ArgV *a,const char *cwd);
