@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.87.2.1 2007/04/05 13:23:39 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.87.2.2 2007/08/17 14:54:15 lav Exp $ */
 
 #include <config.h>
 
@@ -655,11 +655,8 @@ const char *NetAccess::DelayingMessage()
 
 bool NetAccess::NextTry()
 {
-   if(max_retries>0 && retries>=max_retries)
-   {
-      Fatal(_("max-retries exceeded"));
+   if(!CheckRetries())
       return false;
-   }
    if(retries==0)
       reconnect_interval_current=reconnect_interval;
    else if(reconnect_interval_multiplier>1)
@@ -668,8 +665,17 @@ bool NetAccess::NextTry()
       if(reconnect_interval_current>reconnect_interval_max)
 	 reconnect_interval_current=reconnect_interval_max;
    }
-   try_time=now;
    retries++;
+   return CheckRetries();
+}
+bool NetAccess::CheckRetries()
+{
+   if(max_retries>0 && retries>max_retries)
+   {
+      Fatal(_("max-retries exceeded"));
+      return false;
+   }
+   try_time=now;
    return true;
 }
 void NetAccess::TrySuccess()
