@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.h,v 1.36 2005/03/01 13:53:11 lav Exp $ */
+/* $Id: NetAccess.h,v 1.42.2.1 2007/08/17 14:54:16 lav Exp $ */
 
 #ifndef NETACCESS_H
 #define NETACCESS_H
 
 #include "FileAccess.h"
 #include "Resolver.h"
+#include "LsCache.h"
 
 class NetAccess : public FileAccess
 {
@@ -39,13 +40,10 @@ protected:
 
    int	 max_retries;
    int	 max_persist_retries;
-   int	 retries;
    int	 persist_retries;
 
-   int	 idle;
-   time_t idle_start;
-
-   int	 timeout;
+   Timer idle_timer;
+   Timer timeout_timer;
    bool	 CheckTimeout();
 
    int	 reconnect_interval;
@@ -67,8 +65,6 @@ protected:
    static void MinimizeLatency(int sock);
    static void MaximizeThroughput(int sock);
    static void ReuseAddress(int sock);
-   static void SetSocketBuffer(int sock,int val);
-   static void SetSocketMaxseg(int sock,int val);
    static int SocketBuffered(int sock);
    static const char *SocketNumericAddress(const sockaddr_u *u);
    static int SocketPort(const sockaddr_u *u);
@@ -76,6 +72,8 @@ protected:
    static int SocketConnect(int fd,const sockaddr_u *u);
    int SocketCreate(int,int,int);
    int SocketCreateTCP(int);
+   int Poll(int fd,int ev);
+   int CheckHangup(const struct pollfd *pfd,int num);
 
    char	 *proxy;
    char	 *proxy_port;
@@ -96,14 +94,13 @@ protected:
 
    const char *DelayingMessage();
    bool ReconnectAllowed();
-   bool NextTry();	// returns false if max-retries exceeded.
+   bool CheckRetries();	// returns false if max-retries exceeded.
+   bool NextTry();	// increments retries; does CheckRetries().
    void TrySuccess();	// reset retry counters.
 
    virtual void HandleTimeout();
 
 public:
-   const char *GetProto() { return "net"; }
-
    void Init();
 
    NetAccess();
@@ -112,12 +109,14 @@ public:
 
    void Reconfig(const char *name=0);
 
-   void ConnectVerify();
+   void Open(const char *fn,int mode,off_t offs);
    void ResetLocationData();
 
    void Close();
 
    int CountConnections();
+
+   static void ClassInit();
 };
 
 class RateLimit
