@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SFtp.cc,v 1.59 2006/06/13 14:35:40 lav Exp $ */
+/* $Id: SFtp.cc,v 1.59.2.2 2007/08/20 08:36:20 lav Exp $ */
 
 #include <config.h>
 #include "SFtp.h"
@@ -31,7 +31,6 @@
 
 #include <assert.h>
 #include <errno.h>
-#include <iconv.h>
 
 #define max_buf 0x10000
 
@@ -279,6 +278,8 @@ int SFtp::Do()
       }
       if(RespQueueSize()>max_packets_in_flight)
 	 return m;
+      if(s>size_write)
+	 s=size_write;
       SendRequest(new Request_WRITE(handle,handle_len,request_pos,b,s),Expect::WRITE_STATUS);
       file_buf->Skip(s);
       request_pos+=s;
