@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1998-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1998-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: buffer.h,v 1.38 2005/11/17 13:03:39 lav Exp $ */
+/* $Id: buffer.h,v 1.40.2.3 2007/08/06 04:49:39 lav Exp $ */
 
 #ifndef BUFFER_H
 #define BUFFER_H
@@ -30,9 +30,12 @@
 #include "xstring.h"
 
 #include <stdarg.h>
+
+#ifdef HAVE_ICONV
 CDECL_BEGIN
 #include <iconv.h>
 CDECL_END
+#endif
 
 #define GET_BUFSIZE 0x10000
 #define PUT_LL_MIN  0x2000
@@ -131,17 +134,19 @@ public:
    enum dir_t { GET, PUT };
 
 protected:
+#ifdef HAVE_ICONV
    iconv_t backend_translate;
+#endif
    Buffer *untranslated;
    dir_t mode;
    void EmbraceNewData(int len);
 
 public:
+#ifdef HAVE_ICONV
    DirectedBuffer(dir_t m) { mode=m; backend_translate=0; untranslated=0; }
    ~DirectedBuffer();
    void SetTranslation(const char *be_encoding,bool translit=true);
    virtual void PutTranslated(const char *buf,int size);
-   void PutTranslated(const char *buf) { PutTranslated(buf,strlen(buf)); }
    void ResetTranslation();
    void Put(const char *buf,int size)
       {
@@ -151,20 +156,25 @@ public:
 	    Buffer::Put(buf,size);
       }
    void Put(const char *buf) { Put(buf,strlen(buf)); }
+#else
+   DirectedBuffer(dir_t m) { mode=m; untranslated=0; }
+   ~DirectedBuffer() { delete untranslated; }
+   void SetTranslation(const char *be_encoding,bool translit=true) {}
+   virtual void PutTranslated(const char *buf,int size) { Put(buf,size); }
+   void ResetTranslation() {}
+#endif
+   void PutTranslated(const char *buf) { PutTranslated(buf,strlen(buf)); }
    dir_t GetDirection() { return mode; }
 };
 
 class IOBuffer : public DirectedBuffer, public SMTask
 {
 protected:
-   time_t event_time; // used to detect timeouts
+   Time event_time; // used to detect timeouts
 
 public:
-   IOBuffer(dir_t m) : DirectedBuffer(m)
-      {
-	 event_time=now;
-      }
-   virtual time_t EventTime()
+   IOBuffer(dir_t m) : DirectedBuffer(m), event_time(now) {}
+   virtual const Time& EventTime()
       {
 	 if(IsSuspended())
 	    return now;
@@ -192,7 +202,7 @@ class IOBufferStacked : public IOBuffer
 public:
    IOBufferStacked(IOBuffer *b) : IOBuffer(b->GetDirection()) { down=b; }
    ~IOBufferStacked() { Delete(down); }
-   time_t EventTime() { return down->EventTime(); }
+   const Time& EventTime() { return down->EventTime(); }
    int Do();
    bool Done();
 };
