@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.h,v 1.137 2006/06/15 14:18:41 lav Exp $ */
+/* $Id: ftpclass.h,v 1.137.2.1 2007/08/20 08:33:58 lav Exp $ */
 
 #ifndef FTPCLASS_H
 #define FTPCLASS_H
@@ -53,7 +53,8 @@ class Ftp : public NetAccess
       DATA_OPEN_STATE,	   // data connection is open, for read or write
       CWD_CWD_WAITING_STATE,  // waiting until 'CWD $cwd' finishes
       USER_RESP_WAITING_STATE,// waiting until 'USER $user' finishes
-      DATASOCKET_CONNECTING_STATE  // waiting for data_sock to connect
+      DATASOCKET_CONNECTING_STATE, // waiting for data_sock to connect
+      WAITING_150_STATE	   // waiting for 150 message
    };
 
 
@@ -83,6 +84,7 @@ class Ftp : public NetAccess
       bool try_feat_after_login;
       bool tune_after_login;
       bool utf8_activated; // server is switched to UTF8 mode.
+      bool received_150;
 
       char type;  // type of transfer: 'A'scii or 'I'mage
 
