@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: pgetJob.h,v 1.9 2004/02/17 10:45:59 lav Exp $ */
+/* $Id: pgetJob.h,v 1.13 2006/07/03 13:23:56 lav Exp $ */
 
 #ifndef PGETJOB_H
 #define PGETJOB_H
@@ -41,20 +41,31 @@ class pgetJob : public GetJob
    ChunkXfer   **chunks;
    int	 max_chunks;
    int	 num_of_chunks;
+   void InitChunks(off_t offset,off_t size);
+
+   off_t start0;
+   off_t limit0;
+
    off_t total_xferred;
    float total_xfer_rate;
 
    bool	no_parallel:1;
    bool chunks_done:1;
+   bool pget_cont:1;
 
    void free_chunks();
-   ChunkXfer *NewChunk(FileAccess *session,const char *remote,
-				FDStream *local,off_t start,off_t limit);
+   ChunkXfer *NewChunk(const char *remote,FDStream *local,off_t start,off_t limit);
 
    long total_eta;
 
+   Timer status_timer;
+   char *status_file;
+   void SaveStatus();
+   void LoadStatus();
+   void LoadStatus0();
+
 protected:
-   void	 NextFile();
+   void NextFile();
 
 public:
    int Do();
@@ -62,17 +73,7 @@ public:
    void PrintStatus(int,const char *);
    void ListJobs(int verbose,int indent=0);
 
-   pgetJob(FileAccess *s,ArgV *args)
-      : GetJob(s,args,/*cont=*/false)
-   {
-      chunks=0;
-      num_of_chunks=0;
-      total_xferred=0;
-      total_xfer_rate=0;
-      no_parallel=false;
-      max_chunks=5;
-      total_eta=-1;
-   }
+   pgetJob(FileAccess *s,ArgV *args,bool cont);
    ~pgetJob();
 
    void SetMaxConn(int n) { max_chunks=n; }
